@@ -5,7 +5,7 @@ import typing as t
 
 from sqlglot import exp
 from sqlglot.errors import ErrorLevel, UnsupportedError, concat_messages
-from sqlglot.helper import apply_index_offset, csv
+from sqlglot.helper import apply_index_offset, csv, seq_get
 from sqlglot.time import format_time
 from sqlglot.tokens import TokenType
 
@@ -417,12 +417,12 @@ class Generator:
 
     def column_sql(self, expression: exp.Column) -> str:
         return ".".join(
-            part
-            for part in [
-                self.sql(expression, "db"),
-                self.sql(expression, "table"),
-                self.sql(expression, "this"),
-            ]
+            self.sql(part)
+            for part in (
+                expression.args.get("schema"),
+                expression.args.get("table"),
+                expression.args.get("this"),
+            )
             if part
         )
 
@@ -453,10 +453,19 @@ class Generator:
         start = expression.args.get("start")
         start = f"START WITH {start}" if start else ""
         increment = expression.args.get("increment")
-        increment = f"INCREMENT BY {increment}" if increment else ""
+        increment = f" INCREMENT BY {increment}" if increment else ""
+        minvalue = expression.args.get("minvalue")
+        minvalue = f" MINVALUE {minvalue}" if minvalue else ""
+        maxvalue = expression.args.get("maxvalue")
+        maxvalue = f" MAXVALUE {maxvalue}" if maxvalue else ""
+        cycle = expression.args.get("cycle")
+        cycle_sql = ""
+        if cycle is not None:
+            cycle_sql = f"{' NO' if not cycle else ''} CYCLE"
+            cycle_sql = cycle_sql.strip() if not start and not increment else cycle_sql
         sequence_opts = ""
-        if start or increment:
-            sequence_opts = f"{start} {increment}"
+        if start or increment or cycle_sql:
+            sequence_opts = f"{start}{increment}{minvalue}{maxvalue}{cycle_sql}"
             sequence_opts = f" ({sequence_opts.strip()})"
         return f"GENERATED{this}AS IDENTITY{sequence_opts}"
 
@@ -920,14 +929,17 @@ class Generator:
         else:
             this = "OVERWRITE TABLE " if overwrite else "INTO "
 
+        alternative = expression.args.get("alternative")
+        alternative = f" OR {alternative} " if alternative else " "
         this = f"{this}{self.sql(expression, 'this')}"
+
         exists = " IF EXISTS " if expression.args.get("exists") else " "
         partition_sql = (
             self.sql(expression, "partition") if expression.args.get("partition") else ""
         )
         expression_sql = self.sql(expression, "expression")
         sep = self.sep() if partition_sql else ""
-        sql = f"INSERT {this}{exists}{partition_sql}{sep}{expression_sql}"
+        sql = f"INSERT{alternative}{this}{exists}{partition_sql}{sep}{expression_sql}"
         return self.prepend_ctes(expression, sql)
 
     def intersect_sql(self, expression: exp.Intersect) -> str:
@@ -1059,21 +1071,26 @@ class Generator:
             f"{self.seg('GROUPING SETS')} {self.wrap(grouping_sets)}" if grouping_sets else ""
         )
 
-        cube = expression.args.get("cube")
-        if cube is True:
-            cube = self.seg("WITH CUBE")
+        cube = expression.args.get("cube", [])
+        if seq_get(cube, 0) is True:
+            return f"{group_by}{self.seg('WITH CUBE')}"
         else:
-            cube = self.expressions(expression, key="cube", indent=False)
-            cube = f"{self.seg('CUBE')} {self.wrap(cube)}" if cube else ""
+            cube_sql = self.expressions(expression, key="cube", indent=False)
+            cube_sql = f"{self.seg('CUBE')} {self.wrap(cube_sql)}" if cube_sql else ""
 
-        rollup = expression.args.get("rollup")
-        if rollup is True:
-            rollup = self.seg("WITH ROLLUP")
+        rollup = expression.args.get("rollup", [])
+        if seq_get(rollup, 0) is True:
+            return f"{group_by}{self.seg('WITH ROLLUP')}"
         else:
-            rollup = self.expressions(expression, key="rollup", indent=False)
-            rollup = f"{self.seg('ROLLUP')} {self.wrap(rollup)}" if rollup else ""
+            rollup_sql = self.expressions(expression, key="rollup", indent=False)
+            rollup_sql = f"{self.seg('ROLLUP')} {self.wrap(rollup_sql)}" if rollup_sql else ""
 
-        return f"{group_by}{csv(grouping_sets, cube, rollup, sep=',')}"
+        groupings = csv(grouping_sets, cube_sql, rollup_sql, sep=",")
+
+        if expression.args.get("expressions") and groupings:
+            group_by = f"{group_by},"
+
+        return f"{group_by}{groupings}"
 
     def having_sql(self, expression: exp.Having) -> str:
         this = self.indent(self.sql(expression, "this"))
@@ -1418,7 +1435,10 @@ class Generator:
         return f"ALL {self.wrap(expression)}"
 
     def any_sql(self, expression: exp.Any) -> str:
-        return f"ANY {self.wrap(expression)}"
+        this = self.sql(expression, "this")
+        if isinstance(expression.this, exp.Subqueryable):
+            this = self.wrap(this)
+        return f"ANY {this}"
 
     def exists_sql(self, expression: exp.Exists) -> str:
         return f"EXISTS{self.wrap(expression)}"
@@ -1896,11 +1916,6 @@ class Generator:
         )
         return f"{this}{expressions}"
 
-    def userdefinedfunctionkwarg_sql(self, expression: exp.UserDefinedFunctionKwarg) -> str:
-        this = self.sql(expression, "this")
-        kind = self.sql(expression, "kind")
-        return f"{this} {kind}"
-
     def joinhint_sql(self, expression: exp.JoinHint) -> str:
         this = self.sql(expression, "this")
         expressions = self.expressions(expression, flat=True)
