@@ -6,6 +6,12 @@ from dataclasses import dataclass, field
 
 from sqlglot import Schema, exp, maybe_parse
 from sqlglot.optimizer import Scope, build_scope, optimize
+from sqlglot.optimizer.expand_laterals import expand_laterals
+from sqlglot.optimizer.qualify_columns import qualify_columns
+from sqlglot.optimizer.qualify_tables import qualify_tables
+
+if t.TYPE_CHECKING:
+    from sqlglot.dialects.dialect import DialectType
 
 
 @dataclass(frozen=True)
@@ -32,7 +38,9 @@ def lineage(
     column: str | exp.Column,
     sql: str | exp.Expression,
     schema: t.Optional[t.Dict | Schema] = None,
-    dialect: t.Optional[str] = None,
+    sources: t.Optional[t.Dict[str, str | exp.Subqueryable]] = None,
+    rules: t.Sequence[t.Callable] = (qualify_tables, qualify_columns, expand_laterals),
+    dialect: DialectType = None,
 ) -> Node:
     """Build the lineage graph for a column of a SQL query.
 
@@ -40,6 +48,8 @@ def lineage(
         column: The column to build the lineage for.
         sql: The SQL string or expression.
         schema: The schema of tables.
+        sources: A mapping of queries which will be used to continue building lineage.
+        rules: Optimizer rules to apply, by default only qualifying tables and columns.
         dialect: The dialect of input SQL.
 
     Returns:
@@ -47,7 +57,17 @@ def lineage(
     """
 
     expression = maybe_parse(sql, dialect=dialect)
-    optimized = optimize(expression, schema=schema)
+
+    if sources:
+        expression = exp.expand(
+            expression,
+            {
+                k: t.cast(exp.Subqueryable, maybe_parse(v, dialect=dialect))
+                for k, v in sources.items()
+            },
+        )
+
+    optimized = optimize(expression, schema=schema, rules=rules)
     scope = build_scope(optimized)
     tables: t.Dict[str, Node] = {}
 
@@ -68,7 +88,7 @@ def lineage(
             return node
 
         select = next(select for select in scope.selects if select.alias_or_name == column_name)
-        source = optimize(scope.expression.select(select, append=False), schema=schema)
+        source = optimize(scope.expression.select(select, append=False), schema=schema, rules=rules)
         select = source.selects[0]
 
         node = Node(
@@ -110,7 +130,7 @@ class LineageHTML:
     def __init__(
         self,
         node: Node,
-        dialect: t.Optional[str] = None,
+        dialect: DialectType = None,
         imports: bool = True,
         **opts: t.Any,
     ):
@@ -140,6 +160,9 @@ class LineageHTML:
             "nodes": {
                 "font": "20px monaco",
                 "shape": "box",
+                "widthConstraint": {
+                    "maximum": 300,
+                },
             },
             **opts,
         }
