@@ -189,6 +189,7 @@ class TokenType(AutoName):
     IF = auto()
     IGNORE_NULLS = auto()
     ILIKE = auto()
+    ILIKE_ANY = auto()
     IN = auto()
     INDEX = auto()
     INNER = auto()
@@ -207,6 +208,7 @@ class TokenType(AutoName):
     LEADING = auto()
     LEFT = auto()
     LIKE = auto()
+    LIKE_ANY = auto()
     LIMIT = auto()
     LOAD_DATA = auto()
     LOCAL = auto()
